@@ -1,6 +1,4 @@
 /***************************************************************************
-                          ksv_core.cpp  -  description
-                             -------------------
     begin                : Sun Oct 3 1999
     copyright            : (C) 1997-99 by Peter Putzer
     email                : putzer@kde.org
