@@ -1,5 +1,4 @@
-/* version.h
-**
+/*
 ** Copyright (C) 2000 Peter Putzer <putzer@kde.org>
 **
 */
@@ -27,7 +26,7 @@
 #ifndef KSV_VERSION_H
 #define KSV_VERSION_H
 
-#define KSYSV_VERSION_STRING "1.3.8 Developer Version" 
+#define KSYSV_VERSION_STRING "1.3.9" 
 
-#endif
+#endif // KSV_VERSION_H
 
